==> haskell-prettyprinter-ansi-terminal-1.1.1.2-19-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-prettyprinter-ansi-terminal.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: prettyprinter-ansi-terminal
version: 1.1.1.2
id: prettyprinter-ansi-terminal-1.1.1.2-HZkFE2JefsfErQGwa0nEsw
key: prettyprinter-ansi-terminal-1.1.1.2-HZkFE2JefsfErQGwa0nEsw
license: BSD-2-Clause
maintainer: David Luposchainsky <dluposchainsky at google>
author: David Luposchainsky
homepage: http://github.com/quchen/prettyprinter
synopsis: ANSI terminal backend for the »prettyprinter« package.
description:
    See README.md
category: User Interfaces, Text
abi: c4fbd8cdd649bc2b6cb3353741482db9
exposed: True
exposed-modules:
    Data.Text.Prettyprint.Doc.Render.Terminal
    Data.Text.Prettyprint.Doc.Render.Terminal.Internal
import-dirs: /usr/lib/ghc-8.4.3/site-local/prettyprinter-ansi-terminal-1.1.1.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/prettyprinter-ansi-terminal-1.1.1.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/prettyprinter-ansi-terminal-1.1.1.2
hs-libraries: HSprettyprinter-ansi-terminal-1.1.1.2-HZkFE2JefsfErQGwa0nEsw
depends:
    base-4.11.1.0 ansi-terminal-0.8.0.4-4zlOvCKnE9eI77dRbIqIB1
    text-1.2.3.0 prettyprinter-1.2.1-3i3d4xCjSqxCVgevcj6TIl
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             ansi-terminal-0.8.0.4-4zlOvCKnE9eI77dRbIqIB1=3720aeddf087c27668b5c651df34c2d3
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             prettyprinter-1.2.1-3i3d4xCjSqxCVgevcj6TIl=14eb1149776b18a5d2cf335b9b251550
haddock-interfaces: /usr/share/doc/haskell-prettyprinter-ansi-terminal/html/prettyprinter-ansi-terminal.haddock
haddock-html: /usr/share/doc/haskell-prettyprinter-ansi-terminal/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-prettyprinter-ansi-terminal-1.1.1.2-20-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-prettyprinter-ansi-terminal.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: prettyprinter-ansi-terminal
version: 1.1.1.2
id: prettyprinter-ansi-terminal-1.1.1.2-25PhxXCtWyunIHNkfHXgp
key: prettyprinter-ansi-terminal-1.1.1.2-25PhxXCtWyunIHNkfHXgp
license: BSD-2-Clause
maintainer: David Luposchainsky <dluposchainsky at google>
author: David Luposchainsky
homepage: http://github.com/quchen/prettyprinter
synopsis: ANSI terminal backend for the »prettyprinter« package.
description:
    See README.md
category: User Interfaces, Text
abi: 58934ec18be41366ecedfa30a871dfea
exposed: True
exposed-modules:
    Data.Text.Prettyprint.Doc.Render.Terminal
    Data.Text.Prettyprint.Doc.Render.Terminal.Internal
import-dirs: /usr/lib/ghc-8.4.3/site-local/prettyprinter-ansi-terminal-1.1.1.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/prettyprinter-ansi-terminal-1.1.1.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/prettyprinter-ansi-terminal-1.1.1.2
hs-libraries: HSprettyprinter-ansi-terminal-1.1.1.2-25PhxXCtWyunIHNkfHXgp
depends:
    base-4.11.1.0 ansi-terminal-0.8.0.4-4zlOvCKnE9eI77dRbIqIB1
    text-1.2.3.0 prettyprinter-1.2.1-8GKo8hGt2bB40TGsLxxCXn
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             ansi-terminal-0.8.0.4-4zlOvCKnE9eI77dRbIqIB1=3720aeddf087c27668b5c651df34c2d3
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             prettyprinter-1.2.1-8GKo8hGt2bB40TGsLxxCXn=b62aaf3751c4db8d6f8dee59599ee292
haddock-interfaces: /usr/share/doc/haskell-prettyprinter-ansi-terminal/html/prettyprinter-ansi-terminal.haddock
haddock-html: /usr/share/doc/haskell-prettyprinter-ansi-terminal/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
